@@ -2,12 +2,12 @@ cal_mobile_server <- function(input, output, session){
   ########## FIRST TAB
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
-  
+
   oldopt <- options()
   on.exit(options(oldopt))
   options(shiny.maxRequestSize=100*1024^2) #file can be up to 50 mb; default is 5 mb
   ## initializations
-  shinyImageFile <- reactiveValues(shiny_img_origin = NULL, shiny_img_cropped = NULL, 
+  shinyImageFile <- reactiveValues(shiny_img_origin = NULL, shiny_img_cropped = NULL,
                                    shiny_img_final = NULL, Threshold = NULL)
   IntensData <- NULL
   ExpInfo <- NULL
@@ -20,7 +20,7 @@ cal_mobile_server <- function(input, output, session){
   LOQ <- NULL
   predFunc <- NULL
   CalibrationData <- NULL
-  
+
   # checks upload for file imput
   observe({
     #default: upload image
@@ -37,14 +37,14 @@ cal_mobile_server <- function(input, output, session){
       shinyImageFile$shiny_img_origin <- img
       shinyImageFile$shiny_img_cropped <- img
       shinyImageFile$shiny_img_final <- img
-      
+
       shinyImageFile$filename <- "sample.TIF"
       #outputs image to plot1 -- main plot
       output$plot1 <- renderPlot({ EBImage::display(shinyImageFile$shiny_img_final, method = "raster") })
     }
     drawCropButtons()
   })
-  
+
   # if the new file is entered, it will become new ImageFile
   observeEvent(input$file1, {
     shinyImageFile$filename <- input$file1$name
@@ -54,13 +54,13 @@ cal_mobile_server <- function(input, output, session){
     shinyImageFile$shiny_img_final <- img
     output$plot1 <- renderPlot({EBImage::display(img, method = "raster")})
   })
-  
+
   drawCropButtons <- function(resetButton=FALSE, segButton=FALSE) {
     output$cropButtons <- renderUI({
       tagList(
         f7Segment(
           if (resetButton) {
-            f7Button("reset", color = "blue", label = "Reset") 
+            f7Button("reset", color = "blue", label = "Reset")
           } else {
             f7Button("no-reset", color = "gray", label = "Reset")
           },
@@ -73,11 +73,11 @@ cal_mobile_server <- function(input, output, session){
       )
     })
   }
-  
+
   # Rotation ----------------------------------------------------------------
-  
+
   observe({reactiveRotation()})
-  
+
   reactiveRotation <- eventReactive(input$rotate, {
     isolate({
       if (!is.null(shinyImageFile$shiny_img_cropped)) {
@@ -88,9 +88,9 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   observe({reactiveRotationCCW()})
-  
+
   reactiveRotationCCW <- eventReactive(input$rotateCCW, {
     isolate({
       if (!is.null(shinyImageFile$shiny_img_cropped)) {
@@ -101,9 +101,9 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   observe({reactiveRotationCW()})
-  
+
   reactiveRotationCW <- eventReactive(input$rotateCW, {
     isolate({
       if (!is.null(shinyImageFile$shiny_img_cropped)) {
@@ -114,9 +114,9 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   observe({reactiveRotationFlip()})
-  
+
   reactiveRotationFlip <- eventReactive(input$fliphor, {
     isolate({
       if (!is.null(shinyImageFile$shiny_img_cropped)) {
@@ -127,9 +127,9 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   observe({reactiveRotationFlop()})
-  
+
   reactiveRotationFlop <- eventReactive(input$flipver, {
     isolate({
       if (!is.null(shinyImageFile$shiny_img_cropped)) {
@@ -139,8 +139,8 @@ cal_mobile_server <- function(input, output, session){
         session$resetBrush("plot_brush")
       }
     })
-  }) 
-  
+  })
+
   croppedImage <- function(image, xmin, ymin, xmax, ymax){
     if(length(dim(image)) == 2)
       image <- image[xmin:xmax, ymin:ymax, drop = FALSE]
@@ -148,9 +148,9 @@ cal_mobile_server <- function(input, output, session){
       image <- image[xmin:xmax, ymin:ymax, ,drop = FALSE]
     return(image)
   }
-  
+
   observe({resetImage()})
-  
+
   resetImage <- eventReactive(input$reset,{
     isolate({
       shinyImageFile$shiny_img_cropped <- shinyImageFile$shiny_img_origin
@@ -161,22 +161,22 @@ cal_mobile_server <- function(input, output, session){
       drawCropButtons()
     })
   })
-  
-  
+
+
   #prompts shiny to look at recursive crop
   observe({recursiveCrop()})
-  
+
   #only executes when selection box is double clicked
   recursiveCrop <- eventReactive(input$plot_dblclick,{
     isolate({
       p <- input$plot_brush
-      validate(need(p$xmax <= dim(shinyImageFile$shiny_img_cropped)[1], 
+      validate(need(p$xmax <= dim(shinyImageFile$shiny_img_cropped)[1],
                     "Highlighted portion is out of bounds on the x-axis"))
-      validate(need(p$ymax <= dim(shinyImageFile$shiny_img_cropped)[2], 
+      validate(need(p$ymax <= dim(shinyImageFile$shiny_img_cropped)[2],
                     "Highlighted portion is out of bounds on the y-axis"))
-      validate(need(p$xmin >= 0, 
+      validate(need(p$xmin >= 0,
                     "Highlighted portion is out of bounds on the x-axis"))
-      validate(need(p$ymin >= 0, 
+      validate(need(p$ymin >= 0,
                     "Highlighted portion is out of bounds on the y-axis"))
       shinyImageFile$shiny_img_cropped <- croppedImage(shinyImageFile$shiny_img_final, p$xmin, p$ymin, p$xmax, p$ymax)
       shinyImageFile$shiny_img_final <- shinyImageFile$shiny_img_cropped
@@ -190,18 +190,18 @@ cal_mobile_server <- function(input, output, session){
     session$resetBrush("plot_brush")
   })
 
-  
+
   observe({recursiveGrid()})
-  
+
   recursiveGrid <- eventReactive(input$plot_brush,{
     isolate({
       p <- input$plot_brush
       output$plot1 <- renderPlot({
         EBImage::display(shinyImageFile$shiny_img_final, method = "raster")
-        
+
         colcuts <- seq(p$xmin, p$xmax, length.out = input$strips + 1)
         rowcuts <- seq(p$ymin, p$ymax, length.out = 2*input$bands) # bands + spaces between bands
-        
+
         for (x in colcuts) {
           lines(x = rep(x, 2), y = c(p$ymin, p$ymax), col="red")
         }
@@ -212,10 +212,10 @@ cal_mobile_server <- function(input, output, session){
       drawCropButtons(segButton = TRUE, resetButton = TRUE)
     })
   })
-  
-  
+
+
   observe({recursiveSegmentation()})
-  
+
   #only executes when Apply Segmentation is clicked
   recursiveSegmentation <- eventReactive(input$segmentation,{
     isolate({
@@ -228,7 +228,7 @@ cal_mobile_server <- function(input, output, session){
         MAX <- dim(shinyImageFile$shiny_img_cropped)[1:2]
         colcuts <- seq(p$xmin, p$xmax, length.out = input$strips + 1)
         rowcuts <- seq(p$ymin, p$ymax, length.out = 2*input$bands)
-        
+
         segmentation.list <- vector("list", length = input$strips)
         count <- 0
         for(i in 1:input$strips){
@@ -251,15 +251,15 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   ################ END OF FIRST TAB
-  
+
   ############## SECOND TAB
   observe({
     input$thresh
     updateF7Stepper("selectStrip", max=input$strips)
   })
-  
+
   showThresholdPlots <- function() {
     output$threshPlots <- renderUI({
       tagList(
@@ -283,7 +283,7 @@ cal_mobile_server <- function(input, output, session){
       )
     })
   }
-  
+
   observe({recursiveThreshold()})
 
   recursiveThreshold <- eventReactive(input$threshold,{
@@ -507,7 +507,7 @@ cal_mobile_server <- function(input, output, session){
       }
     })
   })
-  
+
   output$thresh <- renderText({
     if(!is.null(shinyImageFile$Threshold))
       paste0("Threshold(s): ", paste0(signif(shinyImageFile$Threshold, 4), collapse = ", "))
@@ -520,7 +520,7 @@ cal_mobile_server <- function(input, output, session){
     if(!is.null(shinyImageFile$Threshold))
       paste0("Median intensities: ", paste0(signif(shinyImageFile$Median_Intensities, 4), collapse = ", "))
   })
-    
+
   observe({recursiveData()})
 
   recursiveData <- eventReactive(input$data,{
@@ -585,19 +585,19 @@ cal_mobile_server <- function(input, output, session){
         shinyImageFile$Median_Intensities <- NULL
     })
   })
-  
+
   output$intens <- renderDT({
     DF <- IntensData
     datatable(DF)
   })
-  
+
   observe({recursiveShowIntensData()})
   recursiveShowIntensData <- eventReactive(input$showIntensData,{
     isolate({
-      updateF7Tabs(session=session, id="tabs", selected = "Intensity Data")
+      updateF7Tabs(session=session, id="tabs", selected = "IntensityData")
     })
   })
-  
+
   observe({recursiveDelete()})
   recursiveDelete <- eventReactive(input$deleteData,{
     isolate({
@@ -605,7 +605,7 @@ cal_mobile_server <- function(input, output, session){
       output$intens <- renderDT({})
     })
   })
-  
+
   observe({recursiveDelete2()})
   recursiveDelete2 <- eventReactive(input$deleteData2,{
     isolate({
@@ -614,7 +614,7 @@ cal_mobile_server <- function(input, output, session){
       output$experiment <- renderDT({})
     })
   })
-  
+
   observe({recursiveDelete3()})
   recursiveDelete3 <- eventReactive(input$deleteData3,{
     isolate({
@@ -623,7 +623,7 @@ cal_mobile_server <- function(input, output, session){
       output$calibration <- renderDT({})
     })
   })
-  
+
   observe({recursiveRefresh()})
   recursiveRefresh <- eventReactive(input$refreshData,{
     isolate({
@@ -633,7 +633,7 @@ cal_mobile_server <- function(input, output, session){
       })
     })
   })
-  
+
   observe({recursiveRefresh2()})
   recursiveRefresh2 <- eventReactive(input$refreshData2,{
     isolate({
@@ -643,7 +643,7 @@ cal_mobile_server <- function(input, output, session){
       })
     })
   })
-  
+
   observe({recursiveRefresh3()})
   recursiveRefresh3 <- eventReactive(input$refreshData3,{
     isolate({
@@ -653,13 +653,13 @@ cal_mobile_server <- function(input, output, session){
       })
     })
   })
-  
+
   observe({recursiveExpInfo()})
-  
+
   recursiveExpInfo <- eventReactive(input$expInfo,{
-    updateF7Tabs(session=session, id="tabs", selected = "Experiment Info")
+    updateF7Tabs(session=session, id="tabs", selected = "ExperimentInfo")
   })
-  
+
   observe({recursiveUploadIntens()})
   recursiveUploadIntens <- eventReactive(input$intensFile,{
     isolate({
@@ -675,7 +675,7 @@ cal_mobile_server <- function(input, output, session){
       })
     })
   })
-  
+
   observe({recursiveUploadExpFile()})
   recursiveUploadExpFile <- eventReactive(input$expFile,{
     isolate({
@@ -689,13 +689,13 @@ cal_mobile_server <- function(input, output, session){
       MergedData <<- DF
       suppressWarnings(rm(CalibrationData, pos = 1))
       output$calibration <- renderDT({})
-      
+
       output$experiment <- renderDT({
         datatable(DF)
       })
     })
   })
-  
+
   observe({recursiveUploadPrepFile()})
   recursiveUploadPrepFile <- eventReactive(input$prepFile,{
     isolate({
@@ -713,7 +713,7 @@ cal_mobile_server <- function(input, output, session){
       updateF7Picker("concVar", choices=names(DF))
     })
   })
-  
+
   observe({recursiveMerge()})
   recursiveMerge <- eventReactive(input$merge,{
     isolate({
@@ -729,30 +729,30 @@ cal_mobile_server <- function(input, output, session){
         DF <- merge(ExpInfo, IntensData,
                     by.x = input$mergeExp,
                     by.y = input$mergeIntens, all = TRUE)
-        
+
         MergedData <<- DF
         CalibrationData <<- DF
-        
+
         output$experiment <- renderDT({
           datatable(DF)
         })
       }
     })
   })
-  
+
   observe({recursivePrepare()})
   recursivePrepare <- eventReactive(input$prepare,{
     DF <- MergedData
     CalibrationData <<- DF
-    
+
     output$calibration <- renderDT({
       datatable(DF)
     })
-    
+
     updateF7Tabs(session=session, id="tabs", selected = "Calibration")
   })
-  
-  
+
+
   #Download code
   output$downloadData <- downloadHandler(
     filename = "IntensityData.csv",
@@ -772,7 +772,7 @@ cal_mobile_server <- function(input, output, session){
       write.csv(CalibrationData, file, row.names = FALSE)
     }
   )
-  
+
   observe({recursiveCombReps()})
   recursiveCombReps <- eventReactive(input$combReps,{
     isolate({
@@ -807,21 +807,21 @@ cal_mobile_server <- function(input, output, session){
       rownames(RES) <- 1:nrow(RES)
       RES <- RES[order(RES[,input$combRepsColSI]),]
       CalibrationData <<- RES
-      
+
       output$calibration <- renderDT({
         datatable(RES)
       })
     })
   })
-  
+
   observe({recursiveReshapeWide()})
-  
+
   recursiveReshapeWide <- eventReactive(input$reshapeWide,{
     isolate({
       rm.file <- (colnames(CalibrationData) != colnames(MergedData)[1] &
                     colnames(CalibrationData) != input$reshapeCol)
       DF.split <- split(CalibrationData[,rm.file], CalibrationData[,input$reshapeCol])
-      
+
       N <- length(unique(CalibrationData[,input$reshapeCol]))
       if(N > 1){
         DF <- DF.split[[1]]
@@ -836,13 +836,13 @@ cal_mobile_server <- function(input, output, session){
       }else{
         DF <- CalibrationData
       }
-      
+
       output$calibration <- renderDT({
         datatable(DF)
       })
     })
   })
-  
+
   MODELNUM <- 1
 
   observe({recursiveRunCali()})
@@ -861,36 +861,36 @@ cal_mobile_server <- function(input, output, session){
           verbatimTextOutput("LOQ")
         )
       })
-      
+
       # flush the output and plots
       output$LOB <- renderText({})
       output$LOD <- renderText({})
       output$LOQ <- renderText({})
       output$plot5 <- renderPlot({})
-      
+
       PATH.OUT <- input$folder
       if (!file.exists(PATH.OUT)) dir.create(PATH.OUT)
-      
+
       concVar <- input$concVar
       respVar <- paste0("(",input$respVar,")")
 
       if(input$useLog){
         if(input$chosenModel == "Generalized additive model (gam)"){
           k <- ceiling(length(unique(CalibrationData[,concVar]))/2)
-          FORMULA <- paste0(respVar, " ~ s(log10(", concVar, "), k = ", k, ")")  
+          FORMULA <- paste0(respVar, " ~ s(log10(", concVar, "), k = ", k, ")")
         }else{
-          FORMULA <- paste0(respVar, " ~ log10(", concVar, ")")  
+          FORMULA <- paste0(respVar, " ~ log10(", concVar, ")")
         }
       }else{
         if(input$chosenModel == "Generalized additive model (gam)"){
           k <- ceiling(length(unique(CalibrationData[,concVar]))/2)
-          FORMULA <- paste0(respVar, " ~ s(", concVar, ", k = ", k, ")")  
+          FORMULA <- paste0(respVar, " ~ s(", concVar, ", k = ", k, ")")
         }else{
           FORMULA <- paste0(respVar, " ~ ", concVar)
         }
       }
-      
-      
+
+
       if(input$chosenModel == "Linear model (lm)" && !inherits(try(lm(as.formula(FORMULA), data=CalibrationData), silent = TRUE), "try-error")){
         modelName = "lm"
       } else if(input$chosenModel == "Local polynomial model (loess)" && !inherits(try(loess(as.formula(FORMULA), data = CalibrationData), silent = TRUE), "try-error")){
@@ -912,36 +912,34 @@ cal_mobile_server <- function(input, output, session){
         updateF7Tabs(session=session, id="tabs", selected = "Results")
         return(NULL)
       }
-      
+
       f7Toast(text=paste("Fitting the model..."), position="top", session=session)
-      
+
       SUBSET <- input$subset
-      
+
       FILENAME <<- paste0(format(Sys.time(), "%Y%m%d_%H%M%S_"), input$analysisName)
-      
+
       save(CalibrationData, FORMULA, SUBSET, PATH.OUT,
-           file = paste0(PATH.OUT,"/", FILENAME, "_Data.RData"))
+           file = file.path(PATH.OUT, paste0(FILENAME, "_Data.RData")))
       if (input$chosenModel == "Linear model (lm)") {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(lm).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       } else if (input$chosenModel == "Local polynomial model (loess)") {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(loess).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       } else if (input$chosenModel == "Generalized additive model (gam)") {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(gam).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       }
-      
-      rmarkdown::render(input = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"),
-                        output_file = paste0(PATH.OUT, "/", FILENAME, "_Analysis.html"))
-      
-      # load(file = paste0(PATH.OUT, "/", FILENAME, "Results.RData")) # This line is not necessary, because the parameters are still loaded in the environment.
-      
+
+      rmarkdown::render(input = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")),
+                        output_file = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.html")))
+
       output$modelSummary <- renderPrint({ fit })
-      
+
       output$plot5 <- renderPlot({
         modelPlot
       })
@@ -954,13 +952,13 @@ cal_mobile_server <- function(input, output, session){
       output$LOQ <- renderText({
         paste0("Limit of Quantification (LOQ): ", signif(LOQ, 3))
       })
-      
+
       # Adding the analysis name and model formula to the table
       modelName <- rep(modelName, nrow(CalibrationData))
       modelFormula <- rep(FORMULA, nrow(CalibrationData))
       modelDF <- cbind(modelName, modelFormula, predFunc(CalibrationData))
-      colnames(modelDF) <- c(paste0(input$analysisName, ".model"), 
-                             paste0(input$analysisName, ".formula"), 
+      colnames(modelDF) <- c(paste0(input$analysisName, ".model"),
+                             paste0(input$analysisName, ".formula"),
                              paste0(input$analysisName, ".", input$concVar, ".fit"))
       if(SUBSET != ""){
         subsetIndex <- function (x, subset){
@@ -968,7 +966,7 @@ cal_mobile_server <- function(input, output, session){
           r <- eval(e, x, parent.frame())
           r & !is.na(r)
         }
-        Index <- eval(call("subsetIndex", x = CalibrationData, 
+        Index <- eval(call("subsetIndex", x = CalibrationData,
                            subset = parse(text = SUBSET)))
         modelDF[!Index,] <- NA
       }
@@ -977,29 +975,29 @@ cal_mobile_server <- function(input, output, session){
       output$calibration <- renderDT({
         datatable(DF)
       })
-      
+
       MODELNUM <<- MODELNUM + 1
-      
+
       updateF7Text(session=session, inputId="analysisName", value=paste0("Model", MODELNUM))
-      
+
       updateF7Tabs(session=session, id="tabs", selected = "Results")
     })
   })
-  
+
   observe(resetFolder())
-  
+
   resetFolder <- eventReactive(input$folder,{
     isolate({
       if(substring(input$folder,1,nchar(file.path(fs::path_home()))) != file.path(fs::path_home()))
-        updateTextInput(session=session, inputId = "folder", value = file.path(fs::path_home())) 
+        updateTextInput(session=session, inputId = "folder", value = file.path(fs::path_home()))
     })
   })
-  
+
   observe({recursiveOpenReport()})
-  
+
   recursiveOpenReport <- eventReactive(input$openReport,{
     isolate({
-      browseURL(paste0(input$folder, "/", FILENAME, "_Analysis.html"),
+      browseURL(file.path(input$folder, paste0(FILENAME, "_Analysis.html")),
                 browser = getOption("browser"))
     })
   })
