@@ -572,11 +572,11 @@ cal_server <- function( input, output, session ) {
           shinyImageFile$Median_Intensities <- NULL
         
         # Save the workspace every time you add to intensity data
-        save(shinyImageFile, IntensData, 
-             ExpInfo, MergedData, fit, 
-             modelPlot, LOB, LOD, LOQ,
-             file=file.path(fs::path_home(), "Documents/LFApp/cal_autosave.RData"))
-        showNotification("Workspace saved", duration=2, type="message")
+        # save(shinyImageFile, IntensData, 
+        #      ExpInfo, MergedData, fit, 
+        #      modelPlot, LOB, LOD, LOQ,
+        #      file=file.path(fs::path_home(), "Documents/LFApp/cal_autosave.RData"))
+        # showNotification("Workspace saved", duration=2, type="message")
       }
     })
   })
@@ -868,25 +868,23 @@ cal_server <- function( input, output, session ) {
       FILENAME <<- paste0(format(Sys.time(), "%Y%m%d_%H%M%S_"), input$analysisName)
       
       save(CalibrationData, FORMULA, SUBSET, PATH.OUT,
-           file = paste0(PATH.OUT,"/", FILENAME, "_Data.RData"))
+           file = file.path(PATH.OUT, paste0(FILENAME, "_Data.RData")))
       if (input$chosenModel == 1) {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(lm).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       } else if (input$chosenModel == 2) {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(loess).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       } else if (input$chosenModel == 3) {
         file.copy(from = system.file("markdown", "CalibrationAnalysis(gam).Rmd",
                                      package = "LFApp"),
-                  to = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"))
+                  to = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")))
       }
       
-      rmarkdown::render(input = paste0(PATH.OUT, "/", FILENAME, "_Analysis.Rmd"),
-                        output_file = paste0(PATH.OUT, "/", FILENAME, "_Analysis.html"))
-      
-      # load(file = paste0(PATH.OUT, "/", FILENAME, "Results.RData")) # This line is not necessary, because the parameters are still loaded in the environment.
+      rmarkdown::render(input = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.Rmd")),
+                        output_file = file.path(PATH.OUT, paste0(FILENAME, "_Analysis.html")))
       
       output$modelSummary <- renderPrint({ fit })
       
@@ -949,7 +947,7 @@ cal_server <- function( input, output, session ) {
   
   recursiveOpenReport <- eventReactive(input$openReport,{
     isolate({
-      browseURL(paste0(input$folder, "/", FILENAME, "_Analysis.html"),
+      browseURL(file.path(input$folder, paste0(FILENAME, "_Analysis.html")),
                 browser = getOption("browser"))
     })
   })
