@@ -262,9 +262,9 @@ core_server <- function( input, output, session ) {
       }
       
       # Save the workspace every time you add to intensity data
-      save(shinyImageFile, IntensData,
-           file=file.path(fs::path_home(), "Documents/LFApp/core_autosave.RData"))
-      showNotification("Workspace saved", duration=2, type="message")
+      # save(shinyImageFile, IntensData,
+      #      file=file.path(fs::path_home(), "Documents/LFApp/core_autosave.RData"))
+      # showNotification("Workspace saved", duration=2, type="message")
     })
   })
   
